<!--
Thanks for wanting to report an issue you've found. Please remove this text and fill in the template below.
When doubt, answer as best as you can. The more specific the better.

In most cases you probably want to report an issue to another repository:

* https://github.com/kiibohd/controller
* https://github.com/kiibohd/configurator

Report bugs to this repository if you find bugs with certain KLL expressions not working or if the KLL compiler is behaving in an odd way.

If possible, please provide reproduction steps (and possibly a kll file or kll file snippet) that detail how to arrive on the issue.
Screenshots, gifs, git repo, gist, etc. are all quite useful ways to describe and provide reproduction steps
-->

* **Firmware/Compiling Origin**:
<!-- compulsory, web configurator, controller.git repo, etc. Where you found the problem. -->

* **KLL Snippet**:
<!-- Small KLL snippet isolating the problem.
Can also be a link to a KLL file.
If you are using the configurator, please include the exported JSON file, though a KLL file is preferrable.
-->

* **OS**:
<!-- compulsory, your OS and the version, e.g. macOS High Sierra, Windows 7 SP1, Ubuntu 14.04 LTS, etc. -->

* **Version**:
<!-- Version of the kll.git repo, configurator (or date when used). i.e. Identify where you found the problem. -->

* **Reproduction Steps**:
<!-- steps to reproduce the issue -->

* **Resulting Issue**:
<!-- description of the issue -->

